/*!\file:  CorePointerFromSolutionEnum.cpp
 * \brief: return type of analyses, number of analyses and core solution function.
 */ 

#ifdef HAVE_CONFIG_H
	#include "config.h"
#else
#error "Cannot compile with HAVE_CONFIG_H symbol! run configure first!"
#endif

#include "../toolkits/toolkits.h"
#include "../objects/objects.h"
#include "../shared/shared.h"
#include "../EnumDefinitions/EnumDefinitions.h"
#include "./solutions.h"
#include "../modules/modules.h"
#include "../include/include.h"
#include "../solvers/solvers.h"

void CorePointerFromSolutionEnum(void (**psolutioncore)(FemModel*),int solutiontype){

	/*output: */
	void (*solutioncore)(FemModel*)=NULL;

	switch(solutiontype){
	
		case DiagnosticSolutionEnum:
			solutioncore=&diagnostic_core;
			break;
		case SteadystateSolutionEnum:
			solutioncore=&steadystate_core;
			break;
		case ThermalSolutionEnum:
			solutioncore=&thermal_core;
			break;
		case PrognosticSolutionEnum:
			solutioncore=&prognostic_core;
			break;
		case BalancedthicknessSolutionEnum:
			solutioncore=&balancedthickness_core;
			break;
		case BalancedvelocitiesSolutionEnum:
			solutioncore=&balancedvelocities_core;
			break;
		case SurfaceSlopeSolutionEnum:
			solutioncore=&surfaceslope_core;
			break;
		case BedSlopeSolutionEnum:
			solutioncore=&bedslope_core;
			break;
		case Transient2DSolutionEnum:
			solutioncore=&transient2d_core;
			break;
		case Transient3DSolutionEnum:
			solutioncore=&transient3d_core;
			break;
		default:
			ISSMERROR("%s%s%s"," solution type: ",EnumToString(solutiontype)," not supported yet!");
			break;
	}
	
	/*Assign output pointer:*/
	ISSMASSERT(psolutioncore);
	*psolutioncore=solutioncore;

}
